import React from "react";
import Link from "next/link";
import Image from "next/image";
import { Button } from "@/components/ui/button";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faBalanceScale } from "@fortawesome/free-solid-svg-icons";

export default function Home() {
  return (
    <div className="min-h-screen font-sans antialiased flex flex-col">
      <header className="py-6 px-8 border-b">
        <div className="container flex items-center justify-between mx-auto">
          <Link href="/" className="flex items-center font-bold text-xl">
            <FontAwesomeIcon icon={faBalanceScale} className="mr-2" />
            PIL-legal
          </Link>
          <nav className="hidden md:flex items-center space-x-6">
            <a href="#" className="hover:underline">
              Features
            </a>
            <a href="#" className="hover:underline">
              About Us
            </a>
            <a href="#" className="hover:underline">
              Contact
            </a>
          </nav>
          <div className="md:hidden">
            {/* Placeholder for mobile menu icon - you can add a hamburger icon here */}
          </div>
        </div>
      </header>

      <main className="flex-grow py-20 px-8">
        <div className="container mx-auto text-center">
          <h1 className="text-4xl sm:text-5xl md:text-6xl font-bold mb-6">
            Justice Accessible to All.
          </h1>
          <p className="text-lg text-muted-foreground mb-10 max-w-xl mx-auto">
            PIL-legal empowers individuals and organizations to champion public
            interest litigation with ease and efficiency. Streamline your PIL
            process, from drafting to case management.
          </p>
          <Button size="lg">Learn More</Button>
          <div className="mt-12">
            <Image
              src="/legal-concept.svg" // Placeholder image - replace with a relevant image
              alt="Legal Concept Illustration"
              width={800}
              height={400}
              className="mx-auto rounded-lg shadow-md dark:invert-0 invert"
              priority
            />
          </div>
        </div>
      </main>

      <section className="py-16 px-8 bg-secondary/10 dark:bg-secondary/20">
        <div className="container mx-auto text-center">
          <h2 className="text-3xl font-semibold mb-8">Key Features</h2>
          <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
            <div>
              <Image
                src="/feature-drafting.svg" // Placeholder icon
                alt="Drafting Icon"
                width={50}
                height={50}
                className="mx-auto mb-4 dark:invert"
              />
              <h3 className="font-semibold mb-2">Guided Drafting</h3>
              <p className="text-sm text-muted-foreground">
                Step-by-step assistance in preparing your PIL drafts, ensuring
                legal compliance.
              </p>
            </div>
            <div>
              <Image
                src="/feature-management.svg" // Placeholder icon
                alt="Management Icon"
                width={50}
                height={50}
                className="mx-auto mb-4 dark:invert"
              />
              <h3 className="font-semibold mb-2">Case Management</h3>
              <p className="text-sm text-muted-foreground">
                Organize and manage all your PIL cases efficiently, tracking
                deadlines and progress.
              </p>
            </div>
            <div>
              <Image
                src="/feature-collaboration.svg" // Placeholder icon
                alt="Collaboration Icon"
                width={50}
                height={50}
                className="mx-auto mb-4 dark:invert"
              />
              <h3 className="font-semibold mb-2">Collaboration Tools</h3>
              <p className="text-sm text-muted-foreground">
                Facilitate teamwork with secure document sharing and
                communication features.
              </p>
            </div>
          </div>
        </div>
      </section>

      <footer className="py-8 px-8 border-t text-center text-sm text-muted-foreground">
        <div className="container mx-auto">
          &copy; {new Date().getFullYear()} PIL-legal. All rights reserved.
        </div>
      </footer>
    </div>
  );
}
